from synctera_client.paths.monitoring_alerts_alert_id.get import ApiForget
from synctera_client.paths.monitoring_alerts_alert_id.patch import ApiForpatch


class MonitoringAlertsAlertId(
    ApiForget,
    ApiForpatch,
):
    pass
