from synctera_client.paths.customers_customer_id.get import ApiForget
from synctera_client.paths.customers_customer_id.put import ApiForput
from synctera_client.paths.customers_customer_id.patch import ApiForpatch


class CustomersCustomerId(
    ApiForget,
    ApiForput,
    ApiForpatch,
):
    pass
