from synctera_client.paths.external_cards_transfers.get import ApiForget
from synctera_client.paths.external_cards_transfers.post import ApiForpost


class ExternalCardsTransfers(
    ApiForget,
    ApiForpost,
):
    pass
