from synctera_client.paths.accounts_templates.get import ApiForget
from synctera_client.paths.accounts_templates.post import ApiForpost


class AccountsTemplates(
    ApiForget,
    ApiForpost,
):
    pass
