from synctera_client.paths.customers_customer_id_watchlists_subscriptions.get import ApiForget
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.post import ApiForpost


class CustomersCustomerIdWatchlistsSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass
