from synctera_client.paths.external_accounts.get import ApiForget
from synctera_client.paths.external_accounts.post import ApiForpost


class ExternalAccounts(
    ApiForget,
    ApiForpost,
):
    pass
