from synctera_client.paths.customers_customer_id_risk_ratings.get import ApiForget
from synctera_client.paths.customers_customer_id_risk_ratings.post import ApiForpost


class CustomersCustomerIdRiskRatings(
    ApiForget,
    ApiForpost,
):
    pass
