from synctera_client.paths.cash_pickups_cash_pickup_id.get import ApiForget
from synctera_client.paths.cash_pickups_cash_pickup_id.patch import ApiForpatch


class CashPickupsCashPickupId(
    ApiForget,
    ApiForpatch,
):
    pass
