from synctera_client.paths.accounts_account_id_relationships_relationship_id.get import ApiForget
from synctera_client.paths.accounts_account_id_relationships_relationship_id.put import ApiForput
from synctera_client.paths.accounts_account_id_relationships_relationship_id.delete import ApiFordelete


class AccountsAccountIdRelationshipsRelationshipId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
