from synctera_client.paths.cards_images_card_image_id.get import ApiForget
from synctera_client.paths.cards_images_card_image_id.patch import ApiForpatch


class CardsImagesCardImageId(
    ApiForget,
    ApiForpatch,
):
    pass
