from synctera_client.paths.monitoring_subscriptions.get import ApiForget
from synctera_client.paths.monitoring_subscriptions.post import ApiForpost


class MonitoringSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass
