# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.customers.post import CreateCustomer
from synctera_client.paths.customers_customer_id_employment.post import CreateCustomerEmployment
from synctera_client.paths.customers_customer_id_risk_ratings.post import CreateCustomerRiskRating
from synctera_client.paths.customers_customer_id_employment.get import GetAllCustomerEmployment
from synctera_client.paths.customers_customer_id_risk_ratings.get import GetAllCustomerRiskRatings
from synctera_client.paths.customers_customer_id.get import GetCustomer
from synctera_client.paths.customers_customer_id_risk_ratings_risk_rating_id.get import GetCustomerRiskRating
from synctera_client.paths.customers_customer_id_employment_employment_id.get import GetPartyEmployment
from synctera_client.paths.customers.get import ListCustomers
from synctera_client.paths.customers_customer_id.patch import PatchCustomer
from synctera_client.paths.customers_customer_id_prefill.post import PrefillCustomer
from synctera_client.paths.customers_customer_id.put import UpdateCustomer
from synctera_client.paths.customers_customer_id_employment_employment_id.put import UpdatePartyEmployment


class CustomersApi(
    CreateCustomer,
    CreateCustomerEmployment,
    CreateCustomerRiskRating,
    GetAllCustomerEmployment,
    GetAllCustomerRiskRatings,
    GetCustomer,
    GetCustomerRiskRating,
    GetPartyEmployment,
    ListCustomers,
    PatchCustomer,
    PrefillCustomer,
    UpdateCustomer,
    UpdatePartyEmployment,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
